package com.bonus.material.ma.service.impl;

import java.util.List;
import com.bonus.common.core.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.bonus.material.ma.mapper.PropInfoMapper;
import com.bonus.material.ma.domain.PropInfo;
import com.bonus.material.ma.service.IPropInfoService;

/**
 * 资产管理Service业务层处理
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Service
public class PropInfoServiceImpl implements IPropInfoService 
{
    @Autowired
    private PropInfoMapper propInfoMapper;

    /**
     * 查询资产管理
     * 
     * @param propId 资产管理主键
     * @return 资产管理
     */
    @Override
    public PropInfo selectPropInfoByPropId(Long propId)
    {
        return propInfoMapper.selectPropInfoByPropId(propId);
    }

    /**
     * 查询资产管理列表
     * 
     * @param propInfo 资产管理
     * @return 资产管理
     */
    @Override
    public List<PropInfo> selectPropInfoList(PropInfo propInfo)
    {
        return propInfoMapper.selectPropInfoList(propInfo);
    }

    /**
     * 新增资产管理
     * 
     * @param propInfo 资产管理
     * @return 结果
     */
    @Override
    public int insertPropInfo(PropInfo propInfo)
    {
        propInfo.setCreateTime(DateUtils.getNowDate());
        return propInfoMapper.insertPropInfo(propInfo);
    }

    /**
     * 修改资产管理
     * 
     * @param propInfo 资产管理
     * @return 结果
     */
    @Override
    public int updatePropInfo(PropInfo propInfo)
    {
        propInfo.setUpdateTime(DateUtils.getNowDate());
        return propInfoMapper.updatePropInfo(propInfo);
    }

    /**
     * 批量删除资产管理
     * 
     * @param propIds 需要删除的资产管理主键
     * @return 结果
     */
    @Override
    public int deletePropInfoByPropIds(Long[] propIds)
    {
        return propInfoMapper.deletePropInfoByPropIds(propIds);
    }

    /**
     * 删除资产管理信息
     * 
     * @param propId 资产管理主键
     * @return 结果
     */
    @Override
    public int deletePropInfoByPropId(Long propId)
    {
        return propInfoMapper.deletePropInfoByPropId(propId);
    }
}
