package com.bonus.material.ma.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;
import com.bonus.common.log.enums.OperaType;
import com.bonus.material.common.annotation.PreventRepeatSubmit;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.bonus.common.log.annotation.SysLog;
import com.bonus.common.security.annotation.RequiresPermissions;
import com.bonus.material.ma.domain.PropInfo;
import com.bonus.material.ma.service.IPropInfoService;
import com.bonus.common.core.web.controller.BaseController;
import com.bonus.common.core.web.domain.AjaxResult;
import com.bonus.common.core.utils.poi.ExcelUtil;
import com.bonus.common.core.web.page.TableDataInfo;

/**
 * 资产管理Controller
 * 
 * @author xsheng
 * @date 2024-09-27
 */
@Api(tags = "资产管理接口")
@RestController
@RequestMapping("/ma_prop_info")
public class PropInfoController extends BaseController
{
    @Autowired
    private IPropInfoService propInfoService;

    /**
     * 查询资产管理列表
     */
    @ApiOperation(value = "查询资产管理列表")
    @RequiresPermissions("ma:info:list")
    @GetMapping("/list")
    public TableDataInfo list(PropInfo propInfo)
    {
        startPage();
        List<PropInfo> list = propInfoService.selectPropInfoList(propInfo);
        return getDataTable(list);
    }

    /**
     * 导出资产管理列表
     */
    @ApiOperation(value = "导出资产管理列表")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:export")
    @SysLog(title = "资产管理", businessType = OperaType.EXPORT, logType = 1,module = "仓储管理->导出资产管理")
    @PostMapping("/export")
    public void export(HttpServletResponse response, PropInfo propInfo)
    {
        List<PropInfo> list = propInfoService.selectPropInfoList(propInfo);
        ExcelUtil<PropInfo> util = new ExcelUtil<PropInfo>(PropInfo.class);
        util.exportExcel(response, list, "资产管理数据");
    }

    /**
     * 获取资产管理详细信息
     */
    @ApiOperation(value = "获取资产管理详细信息")
    @RequiresPermissions("ma:info:query")
    @GetMapping(value = "/{propId}")
    public AjaxResult getInfo(@PathVariable("propId") Long propId)
    {
        return success(propInfoService.selectPropInfoByPropId(propId));
    }

    /**
     * 新增资产管理
     */
    @ApiOperation(value = "新增资产管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:add")
    @SysLog(title = "资产管理", businessType = OperaType.INSERT, logType = 1,module = "仓储管理->新增资产管理")
    @PostMapping
    public AjaxResult add(@RequestBody PropInfo propInfo)
    {
        return toAjax(propInfoService.insertPropInfo(propInfo));
    }

    /**
     * 修改资产管理
     */
    @ApiOperation(value = "修改资产管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:edit")
    @SysLog(title = "资产管理", businessType = OperaType.UPDATE, logType = 1,module = "仓储管理->修改资产管理")
    @PutMapping
    public AjaxResult edit(@RequestBody PropInfo propInfo)
    {
        return toAjax(propInfoService.updatePropInfo(propInfo));
    }

    /**
     * 删除资产管理
     */
    @ApiOperation(value = "删除资产管理")
    @PreventRepeatSubmit
    @RequiresPermissions("ma:info:remove")
    @SysLog(title = "资产管理", businessType = OperaType.DELETE, logType = 1,module = "仓储管理->删除资产管理")
	@DeleteMapping("/{propIds}")
    public AjaxResult remove(@PathVariable Long[] propIds)
    {
        return toAjax(propInfoService.deletePropInfoByPropIds(propIds));
    }
}
